@@ -150,6 +150,6 @@ def daemon_stop(pidfile, sig=None):
     logger.debug("load pid={pid}".format(pid=pid))
     if not pid:
         six.print_("Application is not running or crashed...", file=os.sys.stderr)
-        os.sys.exit(195)
+        return 0
     process_kill(pid, sig)
     return pid
